@@ -269,6 +269,16 @@ public class GoogleAnalyticsBridge extends ReactContextBaseJavaModule {
         }
     }
 
+    @ReactMethod
+    public void setClient(String trackerId, String clientId)
+    {
+        Tracker tracker = getTracker(trackerId);
+
+        if (tracker != null) {
+            tracker.set("&cid", clientId);
+        }
+    }
+
     @ReactMethod
     public void allowIDFA(String trackerId, Boolean enabled)
     {
@@ -314,6 +324,12 @@ public class GoogleAnalyticsBridge extends ReactContextBaseJavaModule {
 
     @ReactMethod
     public void trackEventWithCustomDimensionValues(String trackerId, String category, String action, ReadableMap optionalValues, ReadableMap dimensionIndexValues)
+    {
+        this.trackEventWithCustomDimensionAndMetricValues(trackerId, category, action, optionalValues, dimensionIndexValues, null);
+    }
+
+    @ReactMethod
+    public void trackEventWithCustomDimensionAndMetricValues(String trackerId, String category, String action, ReadableMap optionalValues, ReadableMap dimensionIndexValues, ReadableMap metricIndexValues)
     {
         Tracker tracker = getTracker(trackerId);
 
@@ -343,6 +359,15 @@ public class GoogleAnalyticsBridge extends ReactContextBaseJavaModule {
                 hit.setCustomDimension(Integer.parseInt(dimensionIndex), dimensionValue);
             }
 
+            if(metricIndexValues != null){
+                ReadableMapKeySetIterator metricIterator = metricIndexValues.keySetIterator();
+                while (metricIterator.hasNextKey()) {
+                    String metricIndex = metricIterator.nextKey();
+                    int metricValue = metricIndexValues.getInt(metricIndex);
+                    hit.setCustomMetric(Integer.parseInt(metricIndex), metricValue);
+                }
+            }
+
             tracker.send(hit.build());
         }
     }
@@ -449,4 +474,11 @@ public class GoogleAnalyticsBridge extends ReactContextBaseJavaModule {
                                         .build());
         }
     }
+  
+    @ReactMethod
+    public void createNewSession(String trackerId, String screenName) {
+        Tracker tracker = getTracker(trackerId);
+        tracker.setScreenName(screenName);
+        tracker.send(new HitBuilders.ScreenViewBuilder().setNewSession().build());
+    }
 }
